merged the autotag-runtime projects into the matching request implementations, as discussed here: http://mail-archives.apache.org/mod_mbox/tiles-dev/201110.mbox/%3CCAHTRnew8sEF+GrT_4PC7_OQcoaJo8zpo592bJSgTTdCo3edE0Q@mail.gmail.com%3E

git-svn-id: https://svn.apache.org/repos/asf/tiles/framework/trunk@1305546 13f79535-47bb-0310-9956-ffa450edef68
diff --git a/tiles-autotag/pom.xml b/tiles-autotag/pom.xml
index 8fc8cdb..6442943 100644
--- a/tiles-autotag/pom.xml
+++ b/tiles-autotag/pom.xml
@@ -57,10 +57,7 @@
         <module>tiles-autotag-core-runtime</module>
         <module>tiles-autotag-core</module>
         <module>tiles-autotag-jsp</module>
-        <module>tiles-autotag-jsp-runtime</module>
-        <module>tiles-autotag-freemarker-runtime</module>
         <module>tiles-autotag-freemarker</module>
-        <module>tiles-autotag-velocity-runtime</module>
         <module>tiles-autotag-velocity</module>
         <module>maven-autotag-plugin</module>
     </modules>
diff --git a/tiles-autotag/tiles-autotag-freemarker-runtime/pom.xml b/tiles-autotag/tiles-autotag-freemarker-runtime/pom.xml
deleted file mode 100644
index 2faf426..0000000
--- a/tiles-autotag/tiles-autotag-freemarker-runtime/pom.xml
+++ /dev/null
@@ -1,69 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-
-<!--
-Licensed to the Apache Software Foundation (ASF) under one
-or more contributor license agreements.  See the NOTICE file
-distributed with this work for additional information
-regarding copyright ownership.  The ASF licenses this file
-to you under the Apache License, Version 2.0 (the
-"License"); you may not use this file except in compliance
-with the License.  You may obtain a copy of the License at
-
-  http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing,
-software distributed under the License is distributed on an
-"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-KIND, either express or implied.  See the License for the
-specific language governing permissions and limitations
-under the License.
--->
-
-<project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/maven-v4_0_0.xsd">
-  <modelVersion>4.0.0</modelVersion>
-  <parent>
-    <artifactId>tiles-autotag</artifactId>
-    <groupId>org.apache.tiles</groupId>
-    <version>1.0-SNAPSHOT</version>
-  </parent>
-  <groupId>org.apache.tiles</groupId>
-  <artifactId>tiles-autotag-freemarker-runtime</artifactId>
-  <version>1.0-SNAPSHOT</version>
-  <name>Autotag - Freemarker runtime classes</name>
-  <description>Runtime classes for Autotag-Freemarker support.</description>
-  <dependencies>
-  	<dependency>
-  		<groupId>org.apache.tiles</groupId>
-  		<artifactId>tiles-autotag-core-runtime</artifactId>
-  		<version>1.0-SNAPSHOT</version>
-  	</dependency>
-  	<dependency>
-  		<groupId>org.freemarker</groupId>
-  		<artifactId>freemarker</artifactId>
-  		<version>2.3.16</version>
-  	</dependency>
-  	<dependency>
-  		<groupId>org.apache.tiles</groupId>
-  		<artifactId>tiles-request-freemarker</artifactId>
-  		<version>1.0-SNAPSHOT</version>
-  	</dependency>
-  	<dependency>
-  		<groupId>junit</groupId>
-  		<artifactId>junit</artifactId>
-  		<version>4.8.2</version>
-  		<scope>test</scope>
-  	</dependency>
-  	<dependency>
-  		<groupId>org.easymock</groupId>
-  		<artifactId>easymock</artifactId>
-  		<version>3.0</version>
-  		<scope>test</scope>
-  	</dependency>
-  	<dependency>
-  		<groupId>javax.servlet</groupId>
-  		<artifactId>servlet-api</artifactId>
-  		<version>2.5</version>
-  		<scope>test</scope>
-  	</dependency>
-  </dependencies>
-</project>
diff --git a/tiles-autotag/tiles-autotag-freemarker-runtime/src/site/site.xml b/tiles-autotag/tiles-autotag-freemarker-runtime/src/site/site.xml
deleted file mode 100644
index b2c2751..0000000
--- a/tiles-autotag/tiles-autotag-freemarker-runtime/src/site/site.xml
+++ /dev/null
@@ -1,56 +0,0 @@
-<?xml version="1.0" encoding="ISO-8859-1"?>
-<!--
-/*
- * $Id: site.xml 1081442 2011-03-14 16:21:08Z apetrelli $
- *
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
--->
-<project name="Apache - Tiles Autotags">
-    <bannerLeft>
-        <name>Apache Software Foundation</name>
-        <src>http://www.apache.org/images/asf-logo.gif</src>
-        <href>http://www.apache.org</href>
-    </bannerLeft>
-    <bannerRight>
-        <name>Apache Tiles&#8482;</name>
-        <src>http://tiles.apache.org/images/logo.png</src>
-        <href>http://tiles.apache.org</href>
-    </bannerRight>
-    <body>
-
-        <links>
-            <item name="Apache" href="http://www.apache.org" />
-            <item name="Tiles" href="http://tiles.apache.org" />
-        </links>
-
-
-        <menu name="Apache Tiles&#8482;">
-            <item
-                   name="Tiles Home"
-                   href="../../index.html"/>
-            <item
-                   name="Tiles Autotags"
-                   href="../index.html"/>
-        </menu>
-
-        <menu ref="modules" />
-        <menu ref="reports" />
-
-    </body>
-</project>
diff --git a/tiles-autotag/tiles-autotag-jsp-runtime/pom.xml b/tiles-autotag/tiles-autotag-jsp-runtime/pom.xml
deleted file mode 100644
index c3883e7..0000000
--- a/tiles-autotag/tiles-autotag-jsp-runtime/pom.xml
+++ /dev/null
@@ -1,70 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-
-<!--
-Licensed to the Apache Software Foundation (ASF) under one
-or more contributor license agreements.  See the NOTICE file
-distributed with this work for additional information
-regarding copyright ownership.  The ASF licenses this file
-to you under the Apache License, Version 2.0 (the
-"License"); you may not use this file except in compliance
-with the License.  You may obtain a copy of the License at
-
-  http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing,
-software distributed under the License is distributed on an
-"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-KIND, either express or implied.  See the License for the
-specific language governing permissions and limitations
-under the License.
--->
-
-<project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/maven-v4_0_0.xsd">
-  <modelVersion>4.0.0</modelVersion>
-  <parent>
-    <artifactId>tiles-autotag</artifactId>
-    <groupId>org.apache.tiles</groupId>
-    <version>1.0-SNAPSHOT</version>
-  </parent>
-  <groupId>org.apache.tiles</groupId>
-  <artifactId>tiles-autotag-jsp-runtime</artifactId>
-  <version>1.0-SNAPSHOT</version>
-  <name>Autotag - JSP runtime code</name>
-  <description>Contains classes used by code generated by Autotag - JSP.</description>
-  <dependencies>
-  	<dependency>
-  		<groupId>javax.servlet.jsp</groupId>
-  		<artifactId>jsp-api</artifactId>
-  		<version>2.1</version>
-  		<scope>provided</scope>
-  	</dependency>
-  	<dependency>
-  		<groupId>org.apache.tiles</groupId>
-  		<artifactId>tiles-autotag-core-runtime</artifactId>
-  		<version>1.0-SNAPSHOT</version>
-  	</dependency>
-  	<dependency>
-  		<groupId>org.apache.tiles</groupId>
-  		<artifactId>tiles-request-jsp</artifactId>
-  		<version>1.0-SNAPSHOT</version>
-  	</dependency>
-  	<dependency>
-  		<groupId>junit</groupId>
-  		<artifactId>junit</artifactId>
-  		<version>4.8.2</version>
-  		<scope>test</scope>
-  	</dependency>
-  	<dependency>
-  		<groupId>org.easymock</groupId>
-  		<artifactId>easymock</artifactId>
-  		<version>3.0</version>
-  		<scope>test</scope>
-  	</dependency>
-  	<dependency>
-  		<groupId>javax.servlet</groupId>
-  		<artifactId>servlet-api</artifactId>
-  		<version>2.5</version>
-  		<scope>test</scope>
-  	</dependency>
-  </dependencies>
-</project>
diff --git a/tiles-autotag/tiles-autotag-jsp-runtime/src/site/site.xml b/tiles-autotag/tiles-autotag-jsp-runtime/src/site/site.xml
deleted file mode 100644
index b2c2751..0000000
--- a/tiles-autotag/tiles-autotag-jsp-runtime/src/site/site.xml
+++ /dev/null
@@ -1,56 +0,0 @@
-<?xml version="1.0" encoding="ISO-8859-1"?>
-<!--
-/*
- * $Id: site.xml 1081442 2011-03-14 16:21:08Z apetrelli $
- *
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
--->
-<project name="Apache - Tiles Autotags">
-    <bannerLeft>
-        <name>Apache Software Foundation</name>
-        <src>http://www.apache.org/images/asf-logo.gif</src>
-        <href>http://www.apache.org</href>
-    </bannerLeft>
-    <bannerRight>
-        <name>Apache Tiles&#8482;</name>
-        <src>http://tiles.apache.org/images/logo.png</src>
-        <href>http://tiles.apache.org</href>
-    </bannerRight>
-    <body>
-
-        <links>
-            <item name="Apache" href="http://www.apache.org" />
-            <item name="Tiles" href="http://tiles.apache.org" />
-        </links>
-
-
-        <menu name="Apache Tiles&#8482;">
-            <item
-                   name="Tiles Home"
-                   href="../../index.html"/>
-            <item
-                   name="Tiles Autotags"
-                   href="../index.html"/>
-        </menu>
-
-        <menu ref="modules" />
-        <menu ref="reports" />
-
-    </body>
-</project>
diff --git a/tiles-autotag/tiles-autotag-velocity-runtime/pom.xml b/tiles-autotag/tiles-autotag-velocity-runtime/pom.xml
deleted file mode 100644
index 2a6e062..0000000
--- a/tiles-autotag/tiles-autotag-velocity-runtime/pom.xml
+++ /dev/null
@@ -1,68 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-
-<!--
-Licensed to the Apache Software Foundation (ASF) under one
-or more contributor license agreements.  See the NOTICE file
-distributed with this work for additional information
-regarding copyright ownership.  The ASF licenses this file
-to you under the Apache License, Version 2.0 (the
-"License"); you may not use this file except in compliance
-with the License.  You may obtain a copy of the License at
-
-  http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing,
-software distributed under the License is distributed on an
-"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-KIND, either express or implied.  See the License for the
-specific language governing permissions and limitations
-under the License.
--->
-
-<project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/maven-v4_0_0.xsd">
-  <modelVersion>4.0.0</modelVersion>
-  <parent>
-    <artifactId>tiles-autotag</artifactId>
-    <groupId>org.apache.tiles</groupId>
-    <version>1.0-SNAPSHOT</version>
-  </parent>
-  <groupId>org.apache.tiles</groupId>
-  <artifactId>tiles-autotag-velocity-runtime</artifactId>
-  <version>1.0-SNAPSHOT</version>
-  <name>Autotag - Velocity runtime classes</name>
-  <description>Runtime code for Velocity directives using template models.</description>
-  <dependencies>
-  	<dependency>
-  		<groupId>org.apache.velocity</groupId>
-  		<artifactId>velocity</artifactId>
-  		<version>1.6.3</version>
-  	</dependency>
-  	<dependency>
-  		<groupId>org.apache.tiles</groupId>
-  		<artifactId>tiles-autotag-core-runtime</artifactId>
-  		<version>1.0-SNAPSHOT</version>
-  	</dependency>
-  	<dependency>
-  		<groupId>org.apache.velocity</groupId>
-  		<artifactId>velocity-tools</artifactId>
-  		<version>2.0</version>
-  	</dependency>
-  	<dependency>
-  		<groupId>org.apache.tiles</groupId>
-  		<artifactId>tiles-request-velocity</artifactId>
-  		<version>1.0-SNAPSHOT</version>
-  	</dependency>
-  	<dependency>
-  		<groupId>org.easymock</groupId>
-  		<artifactId>easymock</artifactId>
-  		<version>3.0</version>
-  		<scope>test</scope>
-  	</dependency>
-  	<dependency>
-  		<groupId>junit</groupId>
-  		<artifactId>junit</artifactId>
-  		<version>4.8.2</version>
-  		<scope>test</scope>
-  	</dependency>
-  </dependencies>
-</project>
diff --git a/tiles-autotag/tiles-autotag-velocity-runtime/src/site/site.xml b/tiles-autotag/tiles-autotag-velocity-runtime/src/site/site.xml
deleted file mode 100644
index b2c2751..0000000
--- a/tiles-autotag/tiles-autotag-velocity-runtime/src/site/site.xml
+++ /dev/null
@@ -1,56 +0,0 @@
-<?xml version="1.0" encoding="ISO-8859-1"?>
-<!--
-/*
- * $Id: site.xml 1081442 2011-03-14 16:21:08Z apetrelli $
- *
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
--->
-<project name="Apache - Tiles Autotags">
-    <bannerLeft>
-        <name>Apache Software Foundation</name>
-        <src>http://www.apache.org/images/asf-logo.gif</src>
-        <href>http://www.apache.org</href>
-    </bannerLeft>
-    <bannerRight>
-        <name>Apache Tiles&#8482;</name>
-        <src>http://tiles.apache.org/images/logo.png</src>
-        <href>http://tiles.apache.org</href>
-    </bannerRight>
-    <body>
-
-        <links>
-            <item name="Apache" href="http://www.apache.org" />
-            <item name="Tiles" href="http://tiles.apache.org" />
-        </links>
-
-
-        <menu name="Apache Tiles&#8482;">
-            <item
-                   name="Tiles Home"
-                   href="../../index.html"/>
-            <item
-                   name="Tiles Autotags"
-                   href="../index.html"/>
-        </menu>
-
-        <menu ref="modules" />
-        <menu ref="reports" />
-
-    </body>
-</project>
diff --git a/tiles-parent/tiles-jsp/src/main/java/org/apache/tiles/jsp/taglib/UseAttributeTag.java b/tiles-parent/tiles-jsp/src/main/java/org/apache/tiles/jsp/taglib/UseAttributeTag.java
index 0032484..0e90721 100644
--- a/tiles-parent/tiles-jsp/src/main/java/org/apache/tiles/jsp/taglib/UseAttributeTag.java
+++ b/tiles-parent/tiles-jsp/src/main/java/org/apache/tiles/jsp/taglib/UseAttributeTag.java
@@ -177,7 +177,7 @@
     /** {@inheritDoc} */
     @Override
     public void doTag() throws JspException, IOException {
-        AutotagRuntime runtime = new org.apache.tiles.autotag.jsp.runtime.JspAutotagRuntime();
+        AutotagRuntime runtime = new org.apache.tiles.request.jsp.autotag.JspAutotagRuntime();
         if (runtime instanceof SimpleTagSupport) {
             SimpleTagSupport tag = (SimpleTagSupport) runtime;
             tag.setJspContext(getJspContext());
diff --git a/tiles-request/tiles-request-freemarker/pom.xml b/tiles-request/tiles-request-freemarker/pom.xml
index 863f0db..d10b90e 100644
--- a/tiles-request/tiles-request-freemarker/pom.xml
+++ b/tiles-request/tiles-request-freemarker/pom.xml
@@ -77,5 +77,11 @@
   		<version>2.5.2</version>
   		<scope>test</scope>
   	</dependency>
+  	<dependency>
+  		<groupId>org.apache.tiles</groupId>
+  		<artifactId>tiles-autotag-core-runtime</artifactId>
+  		<version>1.0-SNAPSHOT</version>
+  		<optional>true</optional>
+  	</dependency>
   </dependencies>
 </project>
diff --git a/tiles-autotag/tiles-autotag-freemarker-runtime/src/main/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerAutotagException.java b/tiles-request/tiles-request-freemarker/src/main/java/org/apache/tiles/request/freemarker/autotag/FreemarkerAutotagException.java
similarity index 96%
rename from tiles-autotag/tiles-autotag-freemarker-runtime/src/main/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerAutotagException.java
rename to tiles-request/tiles-request-freemarker/src/main/java/org/apache/tiles/request/freemarker/autotag/FreemarkerAutotagException.java
index 6f11f10..04df896 100644
--- a/tiles-autotag/tiles-autotag-freemarker-runtime/src/main/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerAutotagException.java
+++ b/tiles-request/tiles-request-freemarker/src/main/java/org/apache/tiles/request/freemarker/autotag/FreemarkerAutotagException.java
@@ -18,7 +18,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.tiles.autotag.freemarker.runtime;
+package org.apache.tiles.request.freemarker.autotag;
 
 /**
  * Thrown when a Freemarker problem under Autotag runtime part happens.
diff --git a/tiles-autotag/tiles-autotag-freemarker-runtime/src/main/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerAutotagRuntime.java b/tiles-request/tiles-request-freemarker/src/main/java/org/apache/tiles/request/freemarker/autotag/FreemarkerAutotagRuntime.java
similarity index 97%
rename from tiles-autotag/tiles-autotag-freemarker-runtime/src/main/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerAutotagRuntime.java
rename to tiles-request/tiles-request-freemarker/src/main/java/org/apache/tiles/request/freemarker/autotag/FreemarkerAutotagRuntime.java
index 64ada57..9eabac3 100644
--- a/tiles-autotag/tiles-autotag-freemarker-runtime/src/main/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerAutotagRuntime.java
+++ b/tiles-request/tiles-request-freemarker/src/main/java/org/apache/tiles/request/freemarker/autotag/FreemarkerAutotagRuntime.java
@@ -18,7 +18,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.tiles.autotag.freemarker.runtime;
+package org.apache.tiles.request.freemarker.autotag;
 
 import java.util.Map;
 
diff --git a/tiles-autotag/tiles-autotag-freemarker-runtime/src/main/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerModelBody.java b/tiles-request/tiles-request-freemarker/src/main/java/org/apache/tiles/request/freemarker/autotag/FreemarkerModelBody.java
similarity index 96%
rename from tiles-autotag/tiles-autotag-freemarker-runtime/src/main/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerModelBody.java
rename to tiles-request/tiles-request-freemarker/src/main/java/org/apache/tiles/request/freemarker/autotag/FreemarkerModelBody.java
index 13c5e84..a006bca 100644
--- a/tiles-autotag/tiles-autotag-freemarker-runtime/src/main/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerModelBody.java
+++ b/tiles-request/tiles-request-freemarker/src/main/java/org/apache/tiles/request/freemarker/autotag/FreemarkerModelBody.java
@@ -18,7 +18,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.tiles.autotag.freemarker.runtime;
+package org.apache.tiles.request.freemarker.autotag;
 
 import java.io.IOException;
 import java.io.Writer;
diff --git a/tiles-autotag/tiles-autotag-freemarker-runtime/src/main/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerUtil.java b/tiles-request/tiles-request-freemarker/src/main/java/org/apache/tiles/request/freemarker/autotag/FreemarkerUtil.java
similarity index 96%
rename from tiles-autotag/tiles-autotag-freemarker-runtime/src/main/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerUtil.java
rename to tiles-request/tiles-request-freemarker/src/main/java/org/apache/tiles/request/freemarker/autotag/FreemarkerUtil.java
index c3a9cbd..0331041 100644
--- a/tiles-autotag/tiles-autotag-freemarker-runtime/src/main/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerUtil.java
+++ b/tiles-request/tiles-request-freemarker/src/main/java/org/apache/tiles/request/freemarker/autotag/FreemarkerUtil.java
@@ -19,7 +19,7 @@
  * under the License.
  */
 
-package org.apache.tiles.autotag.freemarker.runtime;
+package org.apache.tiles.request.freemarker.autotag;
 
 import freemarker.template.TemplateModel;
 import freemarker.template.TemplateModelException;
diff --git a/tiles-autotag/tiles-autotag-freemarker-runtime/src/main/java/org/apache/tiles/autotag/freemarker/runtime/package-info.java b/tiles-request/tiles-request-freemarker/src/main/java/org/apache/tiles/request/freemarker/autotag/package-info.java
similarity index 93%
rename from tiles-autotag/tiles-autotag-freemarker-runtime/src/main/java/org/apache/tiles/autotag/freemarker/runtime/package-info.java
rename to tiles-request/tiles-request-freemarker/src/main/java/org/apache/tiles/request/freemarker/autotag/package-info.java
index 0cb0f7e..fb875dc 100644
--- a/tiles-autotag/tiles-autotag-freemarker-runtime/src/main/java/org/apache/tiles/autotag/freemarker/runtime/package-info.java
+++ b/tiles-request/tiles-request-freemarker/src/main/java/org/apache/tiles/request/freemarker/autotag/package-info.java
@@ -21,4 +21,4 @@
 /**
  * Runtime part of Autotag support for Freemarker.
  */
-package org.apache.tiles.autotag.freemarker.runtime;
+package org.apache.tiles.request.freemarker.autotag;
diff --git a/tiles-autotag/tiles-autotag-freemarker-runtime/src/test/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerAutotagExceptionTest.java b/tiles-request/tiles-request-freemarker/src/test/java/org/apache/tiles/request/freemarker/autotag/FreemarkerAutotagExceptionTest.java
similarity index 94%
rename from tiles-autotag/tiles-autotag-freemarker-runtime/src/test/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerAutotagExceptionTest.java
rename to tiles-request/tiles-request-freemarker/src/test/java/org/apache/tiles/request/freemarker/autotag/FreemarkerAutotagExceptionTest.java
index df54c3b..aac061a 100644
--- a/tiles-autotag/tiles-autotag-freemarker-runtime/src/test/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerAutotagExceptionTest.java
+++ b/tiles-request/tiles-request-freemarker/src/test/java/org/apache/tiles/request/freemarker/autotag/FreemarkerAutotagExceptionTest.java
@@ -19,10 +19,11 @@
  * under the License.
  */
 
-package org.apache.tiles.autotag.freemarker.runtime;
+package org.apache.tiles.request.freemarker.autotag;
 
 import static org.junit.Assert.*;
 
+import org.apache.tiles.request.freemarker.autotag.FreemarkerAutotagException;
 import org.junit.Test;
 
 /**
diff --git a/tiles-autotag/tiles-autotag-freemarker-runtime/src/test/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerAutotagRuntimeTest.java b/tiles-request/tiles-request-freemarker/src/test/java/org/apache/tiles/request/freemarker/autotag/FreemarkerAutotagRuntimeTest.java
similarity index 96%
rename from tiles-autotag/tiles-autotag-freemarker-runtime/src/test/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerAutotagRuntimeTest.java
rename to tiles-request/tiles-request-freemarker/src/test/java/org/apache/tiles/request/freemarker/autotag/FreemarkerAutotagRuntimeTest.java
index 39fc1a4..9a93b21 100644
--- a/tiles-autotag/tiles-autotag-freemarker-runtime/src/test/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerAutotagRuntimeTest.java
+++ b/tiles-request/tiles-request-freemarker/src/test/java/org/apache/tiles/request/freemarker/autotag/FreemarkerAutotagRuntimeTest.java
@@ -18,7 +18,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.tiles.autotag.freemarker.runtime;
+package org.apache.tiles.request.freemarker.autotag;
 
 import static org.easymock.EasyMock.*;
 import static org.junit.Assert.*;
@@ -37,6 +37,8 @@
 import org.apache.tiles.request.ApplicationContext;
 import org.apache.tiles.request.Request;
 import org.apache.tiles.request.freemarker.FreemarkerRequest;
+import org.apache.tiles.request.freemarker.autotag.FreemarkerAutotagRuntime;
+import org.apache.tiles.request.freemarker.autotag.FreemarkerModelBody;
 import org.junit.Test;
 import freemarker.core.Environment;
 import freemarker.core.Macro;
diff --git a/tiles-autotag/tiles-autotag-freemarker-runtime/src/test/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerUtilTest.java b/tiles-request/tiles-request-freemarker/src/test/java/org/apache/tiles/request/freemarker/autotag/FreemarkerUtilTest.java
similarity index 94%
rename from tiles-autotag/tiles-autotag-freemarker-runtime/src/test/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerUtilTest.java
rename to tiles-request/tiles-request-freemarker/src/test/java/org/apache/tiles/request/freemarker/autotag/FreemarkerUtilTest.java
index 627346e..1841b23 100644
--- a/tiles-autotag/tiles-autotag-freemarker-runtime/src/test/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerUtilTest.java
+++ b/tiles-request/tiles-request-freemarker/src/test/java/org/apache/tiles/request/freemarker/autotag/FreemarkerUtilTest.java
@@ -18,7 +18,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.tiles.autotag.freemarker.runtime;
+package org.apache.tiles.request.freemarker.autotag;
 
 import static org.easymock.EasyMock.*;
 import static org.junit.Assert.*;
@@ -26,6 +26,8 @@
 import java.io.Writer;
 import java.util.HashMap;
 
+import org.apache.tiles.request.freemarker.autotag.FreemarkerAutotagException;
+import org.apache.tiles.request.freemarker.autotag.FreemarkerUtil;
 import org.junit.Test;
 
 import freemarker.core.Environment;
diff --git a/tiles-request/tiles-request-jsp/pom.xml b/tiles-request/tiles-request-jsp/pom.xml
index 06ebd7e..c781dcf 100644
--- a/tiles-request/tiles-request-jsp/pom.xml
+++ b/tiles-request/tiles-request-jsp/pom.xml
@@ -87,5 +87,11 @@
 			<version>1.0.5</version>
 			<scope>test</scope>
 		</dependency>
+		<dependency>
+			<groupId>org.apache.tiles</groupId>
+			<artifactId>tiles-autotag-core-runtime</artifactId>
+			<version>1.0-SNAPSHOT</version>
+			<optional>true</optional>
+		</dependency>
 	</dependencies>
 </project>
diff --git a/tiles-autotag/tiles-autotag-jsp-runtime/src/main/java/org/apache/tiles/autotag/jsp/runtime/JspAutotagRuntime.java b/tiles-request/tiles-request-jsp/src/main/java/org/apache/tiles/request/jsp/autotag/JspAutotagRuntime.java
similarity index 97%
rename from tiles-autotag/tiles-autotag-jsp-runtime/src/main/java/org/apache/tiles/autotag/jsp/runtime/JspAutotagRuntime.java
rename to tiles-request/tiles-request-jsp/src/main/java/org/apache/tiles/request/jsp/autotag/JspAutotagRuntime.java
index c7e74cf..9b72230 100644
--- a/tiles-autotag/tiles-autotag-jsp-runtime/src/main/java/org/apache/tiles/autotag/jsp/runtime/JspAutotagRuntime.java
+++ b/tiles-request/tiles-request-jsp/src/main/java/org/apache/tiles/request/jsp/autotag/JspAutotagRuntime.java
@@ -18,7 +18,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.tiles.autotag.jsp.runtime;
+package org.apache.tiles.request.jsp.autotag;
 
 import javax.servlet.jsp.JspContext;
 import javax.servlet.jsp.PageContext;
diff --git a/tiles-autotag/tiles-autotag-jsp-runtime/src/main/java/org/apache/tiles/autotag/jsp/runtime/JspModelBody.java b/tiles-request/tiles-request-jsp/src/main/java/org/apache/tiles/request/jsp/autotag/JspModelBody.java
similarity index 97%
rename from tiles-autotag/tiles-autotag-jsp-runtime/src/main/java/org/apache/tiles/autotag/jsp/runtime/JspModelBody.java
rename to tiles-request/tiles-request-jsp/src/main/java/org/apache/tiles/request/jsp/autotag/JspModelBody.java
index 66a7f5c..8918786 100644
--- a/tiles-autotag/tiles-autotag-jsp-runtime/src/main/java/org/apache/tiles/autotag/jsp/runtime/JspModelBody.java
+++ b/tiles-request/tiles-request-jsp/src/main/java/org/apache/tiles/request/jsp/autotag/JspModelBody.java
@@ -18,7 +18,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.tiles.autotag.jsp.runtime;
+package org.apache.tiles.request.jsp.autotag;
 
 import java.io.IOException;
 import java.io.Writer;
diff --git a/tiles-autotag/tiles-autotag-jsp-runtime/src/main/java/org/apache/tiles/autotag/jsp/runtime/package-info.java b/tiles-request/tiles-request-jsp/src/main/java/org/apache/tiles/request/jsp/autotag/package-info.java
similarity index 94%
rename from tiles-autotag/tiles-autotag-jsp-runtime/src/main/java/org/apache/tiles/autotag/jsp/runtime/package-info.java
rename to tiles-request/tiles-request-jsp/src/main/java/org/apache/tiles/request/jsp/autotag/package-info.java
index 170589e..08adc1b 100644
--- a/tiles-autotag/tiles-autotag-jsp-runtime/src/main/java/org/apache/tiles/autotag/jsp/runtime/package-info.java
+++ b/tiles-request/tiles-request-jsp/src/main/java/org/apache/tiles/request/jsp/autotag/package-info.java
@@ -21,4 +21,4 @@
 /**
  * Runtime part of Autotag support for JavaServer pages.
  */
-package org.apache.tiles.autotag.jsp.runtime;
+package org.apache.tiles.request.jsp.autotag;
diff --git a/tiles-autotag/tiles-autotag-jsp-runtime/src/test/java/org/apache/tiles/autotag/jsp/runtime/JspAutotagRuntimeTest.java b/tiles-request/tiles-request-jsp/src/test/java/org/apache/tiles/request/jsp/autotag/JspAutotagRuntimeTest.java
similarity index 94%
rename from tiles-autotag/tiles-autotag-jsp-runtime/src/test/java/org/apache/tiles/autotag/jsp/runtime/JspAutotagRuntimeTest.java
rename to tiles-request/tiles-request-jsp/src/test/java/org/apache/tiles/request/jsp/autotag/JspAutotagRuntimeTest.java
index 42df5d2..3cb093c 100644
--- a/tiles-autotag/tiles-autotag-jsp-runtime/src/test/java/org/apache/tiles/autotag/jsp/runtime/JspAutotagRuntimeTest.java
+++ b/tiles-request/tiles-request-jsp/src/test/java/org/apache/tiles/request/jsp/autotag/JspAutotagRuntimeTest.java
@@ -1,4 +1,4 @@
-package org.apache.tiles.autotag.jsp.runtime;
+package org.apache.tiles.request.jsp.autotag;
 
 import static org.easymock.EasyMock.*;
 import static org.junit.Assert.*;
@@ -16,6 +16,8 @@
 import org.apache.tiles.request.ApplicationContext;
 import org.apache.tiles.request.Request;
 import org.apache.tiles.request.jsp.JspRequest;
+import org.apache.tiles.request.jsp.autotag.JspAutotagRuntime;
+import org.apache.tiles.request.jsp.autotag.JspModelBody;
 import org.junit.Test;
 
 public class JspAutotagRuntimeTest {
diff --git a/tiles-request/tiles-request-velocity/pom.xml b/tiles-request/tiles-request-velocity/pom.xml
index d0b8451..c78351f 100644
--- a/tiles-request/tiles-request-velocity/pom.xml
+++ b/tiles-request/tiles-request-velocity/pom.xml
@@ -52,7 +52,7 @@
   	<dependency>
   		<groupId>org.easymock</groupId>
   		<artifactId>easymock</artifactId>
-  		<version>2.5.2</version>
+  		<version>3.0</version>
   		<scope>test</scope>
   	</dependency>
   	<dependency>
@@ -66,5 +66,11 @@
   		<artifactId>tiles-request-servlet</artifactId>
   		<version>${project.version}</version>
   	</dependency>
+  	<dependency>
+  		<groupId>org.apache.tiles</groupId>
+  		<artifactId>tiles-autotag-core-runtime</artifactId>
+  		<version>1.0-SNAPSHOT</version>
+  		<optional>true</optional>
+  	</dependency>
   </dependencies>
 </project>
diff --git a/tiles-autotag/tiles-autotag-velocity-runtime/src/main/java/org/apache/tiles/autotag/velocity/runtime/VelocityAutotagRuntime.java b/tiles-request/tiles-request-velocity/src/main/java/org/apache/tiles/request/velocity/autotag/VelocityAutotagRuntime.java
similarity index 98%
rename from tiles-autotag/tiles-autotag-velocity-runtime/src/main/java/org/apache/tiles/autotag/velocity/runtime/VelocityAutotagRuntime.java
rename to tiles-request/tiles-request-velocity/src/main/java/org/apache/tiles/request/velocity/autotag/VelocityAutotagRuntime.java
index 4ed71ce..9d7b419 100644
--- a/tiles-autotag/tiles-autotag-velocity-runtime/src/main/java/org/apache/tiles/autotag/velocity/runtime/VelocityAutotagRuntime.java
+++ b/tiles-request/tiles-request-velocity/src/main/java/org/apache/tiles/request/velocity/autotag/VelocityAutotagRuntime.java
@@ -18,7 +18,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.tiles.autotag.velocity.runtime;
+package org.apache.tiles.request.velocity.autotag;
 
 import java.io.Writer;
 import java.util.Map;
diff --git a/tiles-autotag/tiles-autotag-velocity-runtime/src/main/java/org/apache/tiles/autotag/velocity/runtime/VelocityModelBody.java b/tiles-request/tiles-request-velocity/src/main/java/org/apache/tiles/request/velocity/autotag/VelocityModelBody.java
similarity index 96%
rename from tiles-autotag/tiles-autotag-velocity-runtime/src/main/java/org/apache/tiles/autotag/velocity/runtime/VelocityModelBody.java
rename to tiles-request/tiles-request-velocity/src/main/java/org/apache/tiles/request/velocity/autotag/VelocityModelBody.java
index 5770547..6fed188 100644
--- a/tiles-autotag/tiles-autotag-velocity-runtime/src/main/java/org/apache/tiles/autotag/velocity/runtime/VelocityModelBody.java
+++ b/tiles-request/tiles-request-velocity/src/main/java/org/apache/tiles/request/velocity/autotag/VelocityModelBody.java
@@ -18,7 +18,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.tiles.autotag.velocity.runtime;
+package org.apache.tiles.request.velocity.autotag;
 
 import java.io.IOException;
 import java.io.Writer;
diff --git a/tiles-autotag/tiles-autotag-velocity-runtime/src/main/java/org/apache/tiles/autotag/velocity/runtime/VelocityUtil.java b/tiles-request/tiles-request-velocity/src/main/java/org/apache/tiles/request/velocity/autotag/VelocityUtil.java
similarity index 97%
rename from tiles-autotag/tiles-autotag-velocity-runtime/src/main/java/org/apache/tiles/autotag/velocity/runtime/VelocityUtil.java
rename to tiles-request/tiles-request-velocity/src/main/java/org/apache/tiles/request/velocity/autotag/VelocityUtil.java
index 8546f59..8ae7e4e 100644
--- a/tiles-autotag/tiles-autotag-velocity-runtime/src/main/java/org/apache/tiles/autotag/velocity/runtime/VelocityUtil.java
+++ b/tiles-request/tiles-request-velocity/src/main/java/org/apache/tiles/request/velocity/autotag/VelocityUtil.java
@@ -19,7 +19,7 @@
  * under the License.
  */
 
-package org.apache.tiles.autotag.velocity.runtime;
+package org.apache.tiles.request.velocity.autotag;
 
 import java.util.Map;
 
diff --git a/tiles-autotag/tiles-autotag-velocity-runtime/src/main/java/org/apache/tiles/autotag/velocity/runtime/package-info.java b/tiles-request/tiles-request-velocity/src/main/java/org/apache/tiles/request/velocity/autotag/package-info.java
similarity index 94%
rename from tiles-autotag/tiles-autotag-velocity-runtime/src/main/java/org/apache/tiles/autotag/velocity/runtime/package-info.java
rename to tiles-request/tiles-request-velocity/src/main/java/org/apache/tiles/request/velocity/autotag/package-info.java
index 1b67358..812198c 100644
--- a/tiles-autotag/tiles-autotag-velocity-runtime/src/main/java/org/apache/tiles/autotag/velocity/runtime/package-info.java
+++ b/tiles-request/tiles-request-velocity/src/main/java/org/apache/tiles/request/velocity/autotag/package-info.java
@@ -21,4 +21,4 @@
 /**
  * Runtime part of Autotag support for Velocity.
  */
-package org.apache.tiles.autotag.velocity.runtime;
+package org.apache.tiles.request.velocity.autotag;
diff --git a/tiles-autotag/tiles-autotag-velocity-runtime/src/test/java/org/apache/tiles/autotag/velocity/runtime/VelocityAutotagRuntimeTest.java b/tiles-request/tiles-request-velocity/src/test/java/org/apache/tiles/request/velocity/autotag/VelocityAutotagRuntimeTest.java
similarity index 95%
rename from tiles-autotag/tiles-autotag-velocity-runtime/src/test/java/org/apache/tiles/autotag/velocity/runtime/VelocityAutotagRuntimeTest.java
rename to tiles-request/tiles-request-velocity/src/test/java/org/apache/tiles/request/velocity/autotag/VelocityAutotagRuntimeTest.java
index 41f7595..3fa76fb 100644
--- a/tiles-autotag/tiles-autotag-velocity-runtime/src/test/java/org/apache/tiles/autotag/velocity/runtime/VelocityAutotagRuntimeTest.java
+++ b/tiles-request/tiles-request-velocity/src/test/java/org/apache/tiles/request/velocity/autotag/VelocityAutotagRuntimeTest.java
@@ -1,4 +1,4 @@
-package org.apache.tiles.autotag.velocity.runtime;
+package org.apache.tiles.request.velocity.autotag;
 
 import static org.easymock.EasyMock.*;
 import static org.junit.Assert.*;
@@ -12,6 +12,8 @@
 import org.apache.tiles.request.ApplicationContext;
 import org.apache.tiles.request.Request;
 import org.apache.tiles.request.velocity.VelocityRequest;
+import org.apache.tiles.request.velocity.autotag.VelocityAutotagRuntime;
+import org.apache.tiles.request.velocity.autotag.VelocityModelBody;
 import org.apache.velocity.context.InternalContextAdapter;
 import org.apache.velocity.runtime.parser.node.ASTBlock;
 import org.apache.velocity.runtime.parser.node.ASTMap;
diff --git a/tiles-autotag/tiles-autotag-velocity-runtime/src/test/java/org/apache/tiles/autotag/velocity/runtime/VelocityUtilTest.java b/tiles-request/tiles-request-velocity/src/test/java/org/apache/tiles/request/velocity/autotag/VelocityUtilTest.java
similarity index 94%
rename from tiles-autotag/tiles-autotag-velocity-runtime/src/test/java/org/apache/tiles/autotag/velocity/runtime/VelocityUtilTest.java
rename to tiles-request/tiles-request-velocity/src/test/java/org/apache/tiles/request/velocity/autotag/VelocityUtilTest.java
index 1b70909..633ed9c 100644
--- a/tiles-autotag/tiles-autotag-velocity-runtime/src/test/java/org/apache/tiles/autotag/velocity/runtime/VelocityUtilTest.java
+++ b/tiles-request/tiles-request-velocity/src/test/java/org/apache/tiles/request/velocity/autotag/VelocityUtilTest.java
@@ -18,13 +18,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.tiles.autotag.velocity.runtime;
+package org.apache.tiles.request.velocity.autotag;
 
 import static org.easymock.EasyMock.*;
 import static org.junit.Assert.*;
 
 import java.util.Map;
 
+import org.apache.tiles.request.velocity.autotag.VelocityUtil;
 import org.apache.velocity.context.InternalContextAdapter;
 import org.apache.velocity.runtime.parser.node.ASTMap;
 import org.apache.velocity.runtime.parser.node.Node;
diff --git a/tiles-autotag/tiles-autotag-freemarker-runtime/src/test/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerModelBodyTest.java b/tiles-request/tiles-request-freemarker/src/test/java/org/apache/tiles/request/freemarker/autotag/FreemarkerModelBodyTest.java
similarity index 85%
rename from tiles-autotag/tiles-autotag-freemarker-runtime/src/test/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerModelBodyTest.java
rename to tiles-request/tiles-request-freemarker/src/test/java/org/apache/tiles/request/freemarker/autotag/FreemarkerModelBodyTest.java
index cae2448..30233d5 100644
--- a/tiles-autotag/tiles-autotag-freemarker-runtime/src/test/java/org/apache/tiles/autotag/freemarker/runtime/FreemarkerModelBodyTest.java
+++ b/tiles-request/tiles-request-freemarker/src/test/java/org/apache/tiles/request/freemarker/autotag/FreemarkerModelBodyTest.java
@@ -18,13 +18,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.tiles.autotag.freemarker.runtime;
+package org.apache.tiles.request.freemarker.autotag;
 
 import static org.easymock.EasyMock.*;
 
 import java.io.IOException;
 import java.io.Writer;
 
+import org.apache.tiles.request.freemarker.autotag.FreemarkerModelBody;
 import org.junit.Test;
 
 import freemarker.template.TemplateDirectiveBody;
@@ -38,7 +39,7 @@
 public class FreemarkerModelBodyTest {
 
     /**
      * Test method for {@link org.apache.tiles.autotag.freemarker.runtime.FreemarkerModelBody#evaluate(java.io.Writer)}.
      * @throws IOException If something goes wrong.
      * @throws TemplateException If something goes wrong.
      */
@@ -56,7 +57,7 @@
     }
 
     /**
      * Test method for {@link org.apache.tiles.autotag.freemarker.runtime.FreemarkerModelBody#evaluate(java.io.Writer)}.
      * @throws IOException If something goes wrong.
      * @throws TemplateException If something goes wrong.
      */
@@ -71,7 +72,7 @@
     }
 
     /**
      * Test method for {@link org.apache.tiles.autotag.freemarker.runtime.FreemarkerModelBody#evaluate(java.io.Writer)}.
      * @throws IOException If something goes wrong.
      * @throws TemplateException If something goes wrong.
      */
@@ -38,7 +39,7 @@
 
     /**
-     * Test method for {@link org.apache.tiles.autotag.freemarker.runtime.FreemarkerModelBody#evaluate(java.io.Writer)}.
+     * Test method for {@link org.apache.tiles.request.freemarker.autotag.FreemarkerModelBody#evaluate(java.io.Writer)}.
      * @throws IOException If something goes wrong.
      * @throws TemplateException If something goes wrong.
@@ -56,7 +57,7 @@
 
     /**
-     * Test method for {@link org.apache.tiles.autotag.freemarker.runtime.FreemarkerModelBody#evaluate(java.io.Writer)}.
+     * Test method for {@link org.apache.tiles.request.freemarker.autotag.FreemarkerModelBody#evaluate(java.io.Writer)}.
      * @throws IOException If something goes wrong.
      * @throws TemplateException If something goes wrong.
@@ -71,7 +72,7 @@
 
     /**
-     * Test method for {@link org.apache.tiles.autotag.freemarker.runtime.FreemarkerModelBody#evaluate(java.io.Writer)}.
+     * Test method for {@link org.apache.tiles.request.freemarker.autotag.FreemarkerModelBody#evaluate(java.io.Writer)}.
      * @throws IOException If something goes wrong.
      * @throws TemplateException If something goes wrong.
diff --git a/tiles-autotag/tiles-autotag-jsp-runtime/src/test/java/org/apache/tiles/autotag/jsp/runtime/JspModelBodyTest.java b/tiles-request/tiles-request-jsp/src/test/java/org/apache/tiles/request/jsp/autotag/JspModelBodyTest.java
similarity index 86%
rename from tiles-autotag/tiles-autotag-jsp-runtime/src/test/java/org/apache/tiles/autotag/jsp/runtime/JspModelBodyTest.java
rename to tiles-request/tiles-request-jsp/src/test/java/org/apache/tiles/request/jsp/autotag/JspModelBodyTest.java
index ddcdc57..f00cb24 100644
--- a/tiles-autotag/tiles-autotag-jsp-runtime/src/test/java/org/apache/tiles/autotag/jsp/runtime/JspModelBodyTest.java
+++ b/tiles-request/tiles-request-jsp/src/test/java/org/apache/tiles/request/jsp/autotag/JspModelBodyTest.java
@@ -18,7 +18,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.tiles.autotag.jsp.runtime;
+package org.apache.tiles.request.jsp.autotag;
 
 import static org.easymock.EasyMock.*;
 
@@ -30,6 +30,7 @@
 import javax.servlet.jsp.PageContext;
 import javax.servlet.jsp.tagext.JspFragment;
 
+import org.apache.tiles.request.jsp.autotag.JspModelBody;
 import org.junit.Test;
 
 /**
@@ -40,7 +41,7 @@
 public class JspModelBodyTest {
 
     /**
      * Test method for {@link org.apache.tiles.autotag.freemarker.runtime.JspModelBody#evaluate(java.io.Writer)}.
      * @throws IOException If something goes wrong.
      * @throws JspException If something goes wrong.
      */
@@ -60,7 +61,7 @@
     }
 
     /**
      * Test method for {@link org.apache.tiles.autotag.freemarker.runtime.JspModelBody#evaluate(java.io.Writer)}.
      * @throws IOException If something goes wrong.
      * @throws JspException If something goes wrong.
      */
@@ -78,7 +79,7 @@
     }
 
     /**
      * Test method for {@link org.apache.tiles.autotag.freemarker.runtime.JspModelBody#evaluate(java.io.Writer)}.
      * @throws IOException If something goes wrong.
      * @throws JspException If something goes wrong.
      */
@@ -40,7 +41,7 @@
 
     /**
-     * Test method for {@link org.apache.tiles.autotag.freemarker.runtime.JspModelBody#evaluate(java.io.Writer)}.
+     * Test method for {@link org.apache.tiles.request.jsp.autotag.freemarker.runtime.JspModelBody#evaluate(java.io.Writer)}.
      * @throws IOException If something goes wrong.
      * @throws JspException If something goes wrong.
@@ -60,7 +61,7 @@
 
     /**
-     * Test method for {@link org.apache.tiles.autotag.freemarker.runtime.JspModelBody#evaluate(java.io.Writer)}.
+     * Test method for {@link org.apache.tiles.request.jsp.autotag.freemarker.runtime.JspModelBody#evaluate(java.io.Writer)}.
      * @throws IOException If something goes wrong.
      * @throws JspException If something goes wrong.
@@ -78,7 +79,7 @@
 
     /**
-     * Test method for {@link org.apache.tiles.autotag.freemarker.runtime.JspModelBody#evaluate(java.io.Writer)}.
+     * Test method for {@link org.apache.tiles.request.jsp.autotag.freemarker.runtime.JspModelBody#evaluate(java.io.Writer)}.
      * @throws IOException If something goes wrong.
      * @throws JspException If something goes wrong.
diff --git a/tiles-autotag/tiles-autotag-velocity-runtime/src/test/java/org/apache/tiles/autotag/velocity/runtime/VelocityModelBodyTest.java b/tiles-request/tiles-request-velocity/src/test/java/org/apache/tiles/request/velocity/autotag/VelocityModelBodyTest.java
similarity index 88%
rename from tiles-autotag/tiles-autotag-velocity-runtime/src/test/java/org/apache/tiles/autotag/velocity/runtime/VelocityModelBodyTest.java
rename to tiles-request/tiles-request-velocity/src/test/java/org/apache/tiles/request/velocity/autotag/VelocityModelBodyTest.java
index 39d1d02..bca5efd 100644
--- a/tiles-autotag/tiles-autotag-velocity-runtime/src/test/java/org/apache/tiles/autotag/velocity/runtime/VelocityModelBodyTest.java
+++ b/tiles-request/tiles-request-velocity/src/test/java/org/apache/tiles/request/velocity/autotag/VelocityModelBodyTest.java
@@ -18,13 +18,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.tiles.autotag.velocity.runtime;
+package org.apache.tiles.request.velocity.autotag;
 
 import static org.easymock.EasyMock.*;
 
 import java.io.IOException;
 import java.io.Writer;
 
+import org.apache.tiles.request.velocity.autotag.VelocityModelBody;
 import org.apache.velocity.context.InternalContextAdapter;
 import org.apache.velocity.runtime.parser.node.ASTBlock;
 import org.junit.Test;
@@ -37,7 +38,7 @@
 public class VelocityModelBodyTest {
 
     /**
      * Test method for {@link org.apache.tiles.autotag.velocity.runtime.VelocityModelBody#evaluate(java.io.Writer)}.
      * @throws IOException If something goes wrong.
      */
     @Test
@@ -37,7 +38,7 @@
 
     /**
-     * Test method for {@link org.apache.tiles.autotag.velocity.runtime.VelocityModelBody#evaluate(java.io.Writer)}.
+     * Test method for {@link org.apache.tiles.request.velocity.autotag.VelocityModelBody#evaluate(java.io.Writer)}.
      * @throws IOException If something goes wrong.
      */